@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: buildhash.c,v 1.74 2005/04/28 00:26:06 geoff Exp $";
+    "$Id: buildhash.c,v 1.75 2008-02-21 01:55:36-08 geoff Exp $";
 #endif
 
 #define MAIN
@@ -47,6 +47,10 @@ static char Rcs_Id[] =
 
 /*
  * $Log: buildhash.c,v $
+ * Revision 1.75  2008-02-21 01:55:36-08  geoff
+ * When the hash teable overflows, null out the "next" pointer so that if
+ * the table is used, ispell won't follow a garbage pointer and crash.
+ *
  * Revision 1.74  2005/04/28 00:26:06  geoff
  * Re-count the dictionary file every time, rather than depending on a
  * file to hold the correct count.  This is necessary because the changes
@@ -429,6 +433,7 @@ static void filltable ()
 	    if (freepointer >= hashend)
 		{
 		overflows++;
+		dp->next = NULL;
 		break;
 		}
 	    else
