@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: icombine.c,v 2.30 2001/07/25 21:51:46 geoff Exp $";
+    "$Id: icombine.c,v 2.33 2005/04/20 23:16:32 geoff Exp $";
 #endif
 
 #define MAIN
@@ -31,16 +31,8 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. Any web site or other electronic service that offers ispell for
- *    download or other electronic transfer as a separate entity, in
- *    either source or binary form, must also include a prominent statement
- *    indicating that information about ispell can be obtained from the
- *    following Web site URL:
- *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
- *    If the offering service supports hyperlinks, the aforementioned
- *    Web site must also be offered as a hyperlink.  Condition #4 does
- *    not apply if ispell is offered only as part of a larger, aggregated
- *    product such as a word processor or packaged operating system.
+ * 4. The code that causes the 'ispell -v' command to display a prominent
+ *    link to the official ispell Web site may not be removed.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -60,6 +52,15 @@ static char Rcs_Id[] =
 
 /*
  * $Log: icombine.c,v $
+ * Revision 2.33  2005/04/20 23:16:32  geoff
+ * Rename some variables to make them more meaningful.
+ *
+ * Revision 2.32  2005/04/14 23:11:36  geoff
+ * Add the -w switch.
+ *
+ * Revision 2.31  2005/04/14 14:38:23  geoff
+ * Update license.
+ *
  * Revision 2.30  2001/07/25 21:51:46  geoff
  * Minor license update.
  *
@@ -106,6 +107,7 @@ int main (argc, argv)
     {
     char *	argp;
     char *	preftype = NULL;
+    char *	wchars = NULL;
 
     while (argc > 1  &&  argv[1][0] == '-')
 	{
@@ -124,6 +126,18 @@ int main (argc, argv)
 		    }
 		preftype = argp;
 		break;
+	    case 'w':
+		wchars = (*argv) + 2;
+		if (*wchars == '\0')
+		    {
+		    argv++;
+		    argc--;
+		    if (argc == 0)
+			usage ();
+		    wchars = *argv;
+		    }
+		break;
+		break;
 	    default:
 		usage ();
 		break;
@@ -141,10 +155,12 @@ int main (argc, argv)
     if (yyparse ())			/* Parse the language tables */
 	exit (1);
 
+    initckch (wchars);
+
     if (preftype != NULL)
 	{
-	defdupchar = findfiletype (preftype, 1, (int *) NULL);
-	if (defdupchar < 0
+	defstringgroup = findfiletype (preftype, 1, (int *) NULL);
+	if (defstringgroup < 0
 	  &&  strcmp (preftype, "plain") != 0
 	  &&  strcmp (preftype, "tex") != 0
 	  &&  strcmp (preftype, "nroff") != 0
@@ -154,8 +170,8 @@ int main (argc, argv)
 	    exit (1);
 	    }
 	}
-    if (defdupchar < 0)
-	defdupchar = 0;
+    if (defstringgroup < 0)
+	defstringgroup = 0;
 
     combinedict ();			/* Combine words */
 
