@@ -1,5 +1,7 @@
+#ifndef ISPELL_H_INCLUDED
+#define ISPELL_H_INCLUDED
 /*
- * $Id: ispell.h,v 1.80 2001/07/25 21:51:46 geoff Exp $
+ * $Id: ispell.h,v 1.84 2005/04/28 14:46:51 geoff Exp $
  */
 
 /*
@@ -19,16 +21,8 @@
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. Any web site or other electronic service that offers ispell for
- *    download or other electronic transfer as a separate entity, in
- *    either source or binary form, must also include a prominent statement
- *    indicating that information about ispell can be obtained from the
- *    following Web site URL:
- *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
- *    If the offering service supports hyperlinks, the aforementioned
- *    Web site must also be offered as a hyperlink.  Condition #4 does
- *    not apply if ispell is offered only as part of a larger, aggregated
- *    product such as a word processor or packaged operating system.
+ * 4. The code that causes the 'ispell -v' command to display a prominent
+ *    link to the official ispell Web site may not be removed.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -48,6 +42,19 @@
 
 /*
  * $Log: ispell.h,v $
+ * Revision 1.84  2005/04/28 14:46:51  geoff
+ * Add support for a correction log file.
+ *
+ * Revision 1.83  2005/04/26 22:40:07  geoff
+ * Add double-inclusion protection.  Include config.h to be sure it's
+ * available.
+ *
+ * Revision 1.82  2005/04/20 23:16:32  geoff
+ * Rename some variables to make them more meaningful.
+ *
+ * Revision 1.81  2005/04/14 14:38:23  geoff
+ * Update license.
+ *
  * Revision 1.80  2001/07/25 21:51:46  geoff
  * Minor license update.
  *
@@ -134,6 +141,7 @@
  *
  */
 
+#include "config.h"
 #include <stdio.h>
 
 #ifdef __STDC__
@@ -397,7 +405,7 @@ struct hashheader
     unsigned char stringchars[MAXSTRINGCHARS][MAXSTRINGCHARLEN + 1];
 						/* String chars */
     unsigned int stringdups[MAXSTRINGCHARS];	/* No. of "base" char */
-    int dupnos[MAXSTRINGCHARS];			/* Dup char ID # */
+    int groupnos[MAXSTRINGCHARS];		/* Group char is in # */
     unsigned short magic2;			/* Second magic for dbl chk */
     };
 
@@ -622,7 +630,7 @@ EXTERN int	uerasechar;	/* User's erase character, from stty */
 EXTERN int	ukillchar;	/* User's kill character */
 
 EXTERN unsigned int laststringch; /* Number of last string character */
-EXTERN int	defdupchar;	/* Default duplicate string type */
+EXTERN int	defstringgroup;	/* Default string character group type */
 
 EXTERN unsigned int
 		numpflags;		/* Number of prefix flags in table */
@@ -640,7 +648,8 @@ EXTERN struct strchartype *		/* String character type collection */
 
 EXTERN FILE *	infile;			/* File being corrected */
 EXTERN FILE *	outfile;		/* Corrected copy of infile */
-EXTERN FILE*	sourcefile;		/* File with full input data */
+EXTERN FILE *	sourcefile;		/* File with full input data */
+EXTERN FILE *	logfile;		/* File for logging corrections */
 
 EXTERN char *	askfilename;		/* File specified in -f option */
 
@@ -738,3 +747,5 @@ INIT (int math_mode, 0);
  * m -- looking for a \begin{minipage} argument.
  */
 INIT (char LaTeX_Mode, 'P');
+
+#endif /* ISPELL_H_INCLUDED */
