@@ -1,7 +1,7 @@
 #ifndef MSGS_H_INCLUDED
 #define MSGS_H_INCLUDED
 /*
- * $Id: msgs.h,v 1.45 2005/04/28 00:19:48 geoff Exp $
+ * $Id: msgs.h,v 1.46 2008/02/22 06:19:19 geoff Exp $
  *
  * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
@@ -65,6 +65,9 @@
 
 /*
  * $Log: msgs.h,v $
+ * Revision 1.46  2008/02/22 06:19:19  geoff
+ * Improve the hash overflow message.
+ *
  * Revision 1.45  2005/04/28 00:19:48  geoff
  * Remove obsolete messages related to the count file.
  *
@@ -165,7 +168,7 @@
 				  max, excess
 #define BHASH_C_BAFF_2 \
   "difference between the affix length and the strip length in a given\nreplacement rule, or the affix length if there is no strip string\nin that rule.)\n"
-#define BHASH_C_OVERFLOW	"Hash table overflowed by %d words\n"
+#define BHASH_C_OVERFLOW	"Hash table overflowed by %d word(s).\nYou probably need to run your dictionary through munchlist.\n"
 #define BHASH_C_CANT_OPEN_DICT "Can't open dictionary\n"
 #define BHASH_C_NO_SPACE	"Couldn't allocate hash table\n"
 #define BHASH_C_COLLISION_SPACE "\ncouldn't allocate space for collision\n"
