@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: term.c,v 1.54 2005/04/14 23:11:36 geoff Exp $";
+    "$Id: term.c,v 1.55 2015-02-08 00:35:41-08 geoff Exp $";
 #endif
 
 /*
@@ -46,7 +46,10 @@ static char Rcs_Id[] =
 
 /*
  * $Log: term.c,v $
- * Revision 1.54  2005/04/14 23:11:36  geoff
+ * Revision 1.55  2015-02-08 00:35:41-08  geoff
+ * Add POSIX termios support (thanks to Christian Weisgerber for the patch).
+ *
+ * Revision 1.54  2005-04-14 16:11:36-07  geoff
  * Correctly handle control-Z, including resetting the terminal.  The
  * only remaining problem is that the screen isn't automatically
  * refreshed. (Doing the latter would either require major changes to
@@ -86,7 +89,9 @@ static char Rcs_Id[] =
 #include "ispell.h"
 #include "proto.h"
 #include "msgs.h"
-#ifdef USG
+#if defined(TERMIOS)
+#include <termios.h>
+#elif defined(USG)
 #include <termio.h>
 #else
 #ifndef __DJGPP__
@@ -165,7 +170,10 @@ static int iputch (c)
     return putchar (c);
     }
 
-#ifdef USG
+#if defined(TERMIOS)
+static struct termios	sbuf;
+static struct termios	osbuf;
+#elif defined(USG)
 static struct termio	sbuf;
 static struct termio	osbuf;
 #else
@@ -270,7 +278,27 @@ retry:
 #endif /* SIGTSTP */
 #endif /* TIOCPGRP */
 
-#ifdef USG
+#if defined(TERMIOS)
+    if (!isatty (0))
+	{
+	(void) fprintf (stderr, TERM_C_NO_BATCH);
+	exit (1);
+	}
+    (void) tcgetattr (0, &osbuf);
+    termchanged = 1;
+
+    sbuf = osbuf;
+    sbuf.c_lflag &= ~(ECHO | ECHOK | ECHONL | ICANON);
+    sbuf.c_oflag &= ~(OPOST);
+    sbuf.c_iflag &= ~(INLCR | IGNCR | ICRNL);
+    sbuf.c_cc[VMIN] = 1;
+    sbuf.c_cc[VTIME] = 1;
+    (void) tcsetattr (0, TCSADRAIN, &sbuf);
+
+    uerasechar = osbuf.c_cc[VERASE];
+    ukillchar = osbuf.c_cc[VKILL];
+
+#elif defined(USG)
     if (!isatty (0))
 	{
 	(void) fprintf (stderr, TERM_C_NO_BATCH);
@@ -319,7 +347,7 @@ retry:
 #endif
 #endif
 
-#ifndef USG
+#if !defined(TERMIOS) && !defined(USG)
     (void) ioctl (0, TIOCGETP, (char *) &osbuf);
 #ifdef TIOCGLTC
     (void) ioctl (0, TIOCGLTC, (char *) &oltc);
@@ -340,7 +368,7 @@ retry:
     (void) ioctl (0, TIOCSLTC, (char *) &ltc);
 #endif
 
-#endif /* USG */
+#endif /* TERMIOS && USG */
 
     if ((oldint = signal (SIGINT, SIG_IGN)) != SIG_IGN)
 	(void) signal (SIGINT, done);
@@ -372,7 +400,9 @@ SIGNAL_TYPE done (signo)
 	{
 	if (te)
 	    tputs (te, 1, iputch);
-#ifdef USG
+#if defined(TERMIOS)
+	(void) tcsetattr (0, TCSADRAIN, &osbuf);
+#elif defined(USG)
 	(void) ioctl (0, TCSETAW, (char *) &osbuf);
 #else
 	(void) ioctl (0, TIOCSETP, (char *) &osbuf);
@@ -393,7 +423,9 @@ static SIGNAL_TYPE onstop (signo)
 	imove (li - 1, 0);
 	if (te)
 	    tputs (te, 1, iputch);
-#ifdef USG
+#if defined(TERMIOS)
+	(void) tcsetattr (0, TCSADRAIN, &osbuf);
+#elif defined(USG)
 	(void) ioctl (0, TCSETAW, (char *) &osbuf);
 #else
 	(void) ioctl (0, TIOCSETP, (char *) &osbuf);
@@ -412,7 +444,9 @@ static SIGNAL_TYPE onstop (signo)
     (void) signal (signo, onstop);
     if (termchanged)
 	{
-#ifdef USG
+#if defined(TERMIOS)
+	(void) tcsetattr (0, TCSADRAIN, &sbuf);
+#elif defined(USG)
 	(void) ioctl (0, TCSETAW, (char *) &sbuf);
 #else
 	(void) ioctl (0, TIOCSETP, (char *) &sbuf);
@@ -480,7 +514,9 @@ int shellescape	(buf)
 	}
     argv[i] = NULL;
 
-#ifdef USG
+#if defined(TERMIOS)
+    (void) tcsetattr (0, TCSADRAIN, &osbuf);
+#elif defined(USG)
     (void) ioctl (0, TCSETAW, (char *) &osbuf);
 #else
     (void) ioctl (0, TIOCSETP, (char *) &osbuf);
@@ -526,7 +562,9 @@ int shellescape	(buf)
 	(void) signal (SIGTSTP, onstop);
 #endif
 
-#ifdef USG
+#if defined(TERMIOS)
+    (void) tcsetattr (0, TCSADRAIN, &sbuf);
+#elif defined(USG)
     (void) ioctl (0, TCSETAW, (char *) &sbuf);
 #else
     (void) ioctl (0, TIOCSETP, (char *) &sbuf);
@@ -562,7 +600,9 @@ void shescape (buf)
     char	curdir[MAXPATHLEN];
 #endif
 
-#ifdef USG
+#if defined(TERMIOS)
+    (void) tcsetattr (0, TCSADRAIN, &osbuf);
+#elif defined(USG)
     (void) ioctl (0, TCSETAW, (char *) &osbuf);
 #else
     (void) ioctl (0, TIOCSETP, (char *) &osbuf);
@@ -610,7 +650,9 @@ void shescape (buf)
     chdir (curdir);
 #endif
 
-#ifdef USG
+#if defined(TERMIOS)
+    (void) tcsetattr (0, TCSADRAIN, &sbuf);
+#elif defined(USG)
     (void) ioctl (0, TCSETAW, (char *) &sbuf);
 #else
     (void) ioctl (0, TIOCSETP, (char *) &sbuf);
