@@ -10,15 +10,15 @@
  */
 
 static char * Version_ID[] = {
-    "@(#) International Ispell Version 3.3.02 12 Jun 2005",
+    "@(#) International Ispell Version 3.4.00 8 Feb 2015",
     "@(#) Copyright (c), 1983, by Pace Willisson",
     "@(#) International version Copyright (c) 1987, 1988, 1990-1995, 1999,",
-    "@(#) 2001, 2002, 2005 by Geoff Kuenning, Claremont, CA.",
+    "@(#) 2001, 2002, 2005, 2015 by Geoff Kuenning, Claremont, CA.",
     "@(#) All rights reserved.",
     "@(#)",
     "@(#) The official ispell Web site is at:",
     "@(#)",
-    "@(#)     http://www.lasr.cs.ucla.edu/geoff/ispell.html",
+    "@(#)     http://www.cs.hmc.edu/geoff/ispell.html",
     "@(#)",
     "@(#) You should always check that site to see whether you have the",
     "@(#) latest version of ispell.",
@@ -63,6 +63,6 @@ static char * Version_ID[] = {
 };
 
 static char RCS_Version_ID[] =
-    "$Id: version.h,v 1.59 2005/06/11 22:49:44 geoff Exp $";
+    "$Id: version.h,v 1.60 2015-02-08 16:44:37-08 geoff Exp $";
 
 #endif /* VERSION_H_INCLUDED */
