@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: xgets.c,v 1.26 2001/07/25 21:51:46 geoff Exp $";
+    "$Id: xgets.c,v 1.28 2005/04/14 14:38:23 geoff Exp $";
 #endif
 
 /*
@@ -21,16 +21,8 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. Any web site or other electronic service that offers ispell for
- *    download or other electronic transfer as a separate entity, in
- *    either source or binary form, must also include a prominent statement
- *    indicating that information about ispell can be obtained from the
- *    following Web site URL:
- *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
- *    If the offering service supports hyperlinks, the aforementioned
- *    Web site must also be offered as a hyperlink.  Condition #4 does
- *    not apply if ispell is offered only as part of a larger, aggregated
- *    product such as a word processor or packaged operating system.
+ * 4. The code that causes the 'ispell -v' command to display a prominent
+ *    link to the official ispell Web site may not be removed.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -50,6 +42,12 @@ static char Rcs_Id[] =
 
 /*
  * $Log: xgets.c,v $
+ * Revision 1.28  2005/04/14 14:38:23  geoff
+ * Update license.
+ *
+ * Revision 1.27  2002/02/06 05:58:03  geoff
+ * Janos Mandli: trim trailing whitespace from include-file names
+ *
  * Revision 1.26  2001/07/25 21:51:46  geoff
  * Minor license update.
  *
@@ -74,6 +72,7 @@ static char Rcs_Id[] =
 #include "config.h"
 #include "ispell.h"
 #include "proto.h"
+#include <ctype.h>
 
 char *		xgets P ((char * string, int size, FILE * stream));
 
@@ -148,8 +147,17 @@ char * xgets (str, size, stream)
 	  &&  strncmp (str, Include_File, (unsigned int) Include_Len) == 0)
 	    {
 	    char *	file_name = str + Include_Len;
-
-	    if (current_F - F < MAXINCLUDEFILES  &&  strlen (file_name) != 0)
+	    
+	    if (*file_name != '\0')
+		{
+		char*	p = file_name + strlen (file_name) - 1;
+		while (p >= file_name  &&  isspace (*p))
+		    {
+		    *p = '\0';
+		    --p;
+		    }
+		}
+	    if (current_F - F < MAXINCLUDEFILES  &&  *file_name != '\0')
 		{
 		FILE *	f;
 
